@@ -3,6 +3,7 @@ myRepeat <- function(v,Qrow,Qcol){c(rep(v[1],Qrow),rep(v[2],Qcol))}
 #' @importFrom rlang .data
 #' @importFrom utils head
 #' @importFrom prodlim row.match
+#' @importFrom reshape2 melt
 #----------------------------------------------------------------------------------
 plotMatrix = function(Mat, dimLabels, clustering = NULL, plotOptions = list()){
 
@@ -62,7 +63,7 @@ plotMatrix = function(Mat, dimLabels, clustering = NULL, plotOptions = list()){
   FGRow <- rep(dimLabels[1], times = n1)
   FGCol <- rep(dimLabels[2], times = n2)
 
-  melted_Mat = reshape::melt(t(Mat))
+  melted_Mat <- reshape2::melt(t(Mat))
 
   names(melted_Mat) <- c('names_col','names_row','link')
   if(is.numeric(melted_Mat$names_col)){melted_Mat$names_col <- as.character(melted_Mat$names_col)}
@@ -78,9 +79,6 @@ plotMatrix = function(Mat, dimLabels, clustering = NULL, plotOptions = list()){
   melted_Mat$FG_col <- as.factor(rep(FGCol,  n1))
   if (binary) { melted_Mat$link <- as.factor(melted_Mat$link)}
 
-
-
-
   g <- ggplot(data = melted_Mat, aes(y = .data$names_row, x = .data$names_col, fill = .data$link))
   g <- g + geom_tile()
   if (!binary) {g <-  g +  scale_fill_gradient(low = "white", high = "black", limits = u,na.value = "transparent")}
@@ -97,7 +95,10 @@ plotMatrix = function(Mat, dimLabels, clustering = NULL, plotOptions = list()){
 
   g <- g +  labs(x = '', y = '') +  theme(aspect.ratio = n1/n2, axis.ticks = element_blank(), panel.background = element_rect(fill = "white"))
   if (!is.null(dimLabels[1]) & !is.null(dimLabels[2])){
-    g <- g+ facet_grid(FG_row ~ FG_col,scales = 'free', space = 'free')}
+    #g <- g+ facet_grid(FG_row ~ FG_col,scales = 'free', space = 'free')
+    g <- g+ facet_grid(FG_row ~ FG_col)
+
+    }
   if (!currentOptions$legend){g <- g +theme(legend.position = 'none')}else{
     g <- g +theme(legend.position = currentOptions$legend.position)
     if(!currentOptions$legend.title){g <- g+ theme(legend.title = element_blank())}}
@@ -282,7 +283,7 @@ plotMultipartiteMatrix = function(listMat, E, nbNodes, namesFG,namesLayers, dist
   FGRow <- rep(namesFG, times = nbNodes*GRow)
 
   ############# meltedMat
-  melted_Mat = reshape::melt(t(MetaMat))
+  melted_Mat = reshape2::melt(t(MetaMat))
   names(melted_Mat) <- c('names_col','names_row','link')
   if (all(is.na(melted_Mat$names_col))){melted_Mat$names_col <- rep(1:n2,n1)}
   if (all(is.na(melted_Mat$names_row))){melted_Mat$names_row <- n1 - rep(1:n1,each = n2) + 1}
@@ -305,7 +306,7 @@ plotMultipartiteMatrix = function(listMat, E, nbNodes, namesFG,namesLayers, dist
   ############# PLOT
 
   g <- ggplot2::ggplot(melted_Mat, aes(y = .data$names_row, x = .data$names_col, fill = .data$link))
-  g <- g +  geom_raster()
+  g <- g +  geom_tile()
   g <- g +  theme(axis.ticks = element_blank(),panel.background = element_rect(fill = "white"))
   g <- g +  labs(x = '', y = '')
   g <- g +  scale_x_discrete(drop = TRUE) + scale_y_discrete(drop = TRUE)
@@ -341,8 +342,10 @@ plotMultipartiteMatrix = function(listMat, E, nbNodes, namesFG,namesLayers, dist
   }
 
 
-  g <- g + facet_grid(FG_row~ FG_col, scales = 'free', space = 'free')
+  g <- g + facet_grid(FG_row~ FG_col, scales = 'free')#coord_equal()
+  #g <- g + facet_grid(FG_row~ FG_col, scales = 'free', space = 'free')
 
+  #g <- g + facet_grid(FG_row~ FG_col)
 
 
 
@@ -372,9 +375,6 @@ plotMultipartiteMatrix = function(listMat, E, nbNodes, namesFG,namesLayers, dist
       separCol$nameSepCol[i] <- melted_Mat$names_col[melted_Mat$index_row==1][separCol$sepCol[i]]}
     }
 
-
-
-
     separRow <- data.frame(sepRow = 0.5 + rep(nbNodes*GRow,nbBlocks - 1) -(separate),
                            FG_row = rep(namesFG,nbBlocks-1),
                            FG_row_index = rep(1:nbFG,nbBlocks-1))
@@ -390,6 +390,7 @@ plotMultipartiteMatrix = function(listMat, E, nbNodes, namesFG,namesLayers, dist
   }
 
   if (!is.null(currentOptions$title)){g <- g + ggtitle(currentOptions$title) }
+
   g
 }
 
